@@ -37,6 +37,7 @@ from transformers import (
     AlbertTokenizer,
     BertConfig,
     BertTokenizer,
+    BertweetTokenizer,
     CamembertConfig,
     CamembertTokenizer,
     DistilBertConfig,
@@ -123,6 +124,7 @@ class ClassificationModel:
         MODEL_CLASSES = {
             "albert": (AlbertConfig, AlbertForSequenceClassification, AlbertTokenizer),
             "bert": (BertConfig, BertForSequenceClassification, BertTokenizer),
+            "bertweet": (RobertaConfig, RobertaForSequenceClassification, BertweetTokenizer),
             "camembert": (CamembertConfig, CamembertForSequenceClassification, CamembertTokenizer),
             "distilbert": (DistilBertConfig, DistilBertForSequenceClassification, DistilBertTokenizer),
             "electra": (ElectraConfig, ElectraForSequenceClassification, ElectraTokenizer),
@@ -248,7 +250,18 @@ class ClassificationModel:
             except AttributeError:
                 raise AttributeError("fp16 requires Pytorch >= 1.6. Please update Pytorch or turn off fp16.")
 
-        self.tokenizer = tokenizer_class.from_pretrained(model_name, do_lower_case=self.args.do_lower_case, **kwargs)
+        if model_name in [
+            "vinai/bertweet-base",
+            "vinai/bertweet-covid19-base-cased",
+            "vinai/bertweet-covid19-base-uncased",
+        ]:
+            self.tokenizer = tokenizer_class.from_pretrained(
+                model_name, do_lower_case=self.args.do_lower_case, normalization=True, **kwargs
+            )
+        else:
+            self.tokenizer = tokenizer_class.from_pretrained(
+                model_name, do_lower_case=self.args.do_lower_case, **kwargs
+            )
 
         self.args.model_name = model_name
         self.args.model_type = model_type
@@ -503,8 +516,8 @@ class ClassificationModel:
 
             scaler = amp.GradScaler()
 
-        model.train()
         for _ in train_iterator:
+            model.train()
             if epochs_trained > 0:
                 epochs_trained -= 1
                 continue
@@ -832,14 +845,18 @@ class ClassificationModel:
 
         eval_loss = 0.0
         nb_eval_steps = 0
-        preds = None
-        out_label_ids = None
+        n_batches = len(eval_dataloader)
+        preds = np.empty((len(eval_dataset), self.num_labels))
+        if multi_label:
+            out_label_ids = np.empty((len(eval_dataset), self.num_labels))
+        else:
+            out_label_ids = np.empty((len(eval_dataset)))
         model.eval()
 
         if self.args.fp16:
             from torch.cuda import amp
 
-        for batch in tqdm(eval_dataloader, disable=args.silent or silent, desc="Running Evaluation"):
+        for i, batch in enumerate(tqdm(eval_dataloader, disable=args.silent or silent, desc="Running Evaluation")):
             # batch = tuple(t.to(device) for t in batch)
 
             with torch.no_grad():
@@ -861,12 +878,17 @@ class ClassificationModel:
 
             nb_eval_steps += 1
 
-            if preds is None:
-                preds = logits.detach().cpu().numpy()
-                out_label_ids = inputs["labels"].detach().cpu().numpy()
-            else:
-                preds = np.append(preds, logits.detach().cpu().numpy(), axis=0)
-                out_label_ids = np.append(out_label_ids, inputs["labels"].detach().cpu().numpy(), axis=0)
+            start_index = self.args.eval_batch_size * i
+            end_index = start_index + self.args.eval_batch_size if i != (n_batches - 1) else len(eval_dataset)
+            preds[start_index:end_index] = logits.detach().cpu().numpy()
+            out_label_ids[start_index:end_index] = inputs["labels"].detach().cpu().numpy()
+
+            # if preds is None:
+            #     preds = logits.detach().cpu().numpy()
+            #     out_label_ids = inputs["labels"].detach().cpu().numpy()
+            # else:
+            #     preds = np.append(preds, logits.detach().cpu().numpy(), axis=0)
+            #     out_label_ids = np.append(out_label_ids, inputs["labels"].detach().cpu().numpy(), axis=0)
 
         eval_loss = eval_loss / nb_eval_steps
 
@@ -1108,15 +1130,20 @@ class ClassificationModel:
 
         eval_loss = 0.0
         nb_eval_steps = 0
-        preds = None
-        out_label_ids = None
+        preds = np.empty((len(to_predict), self.num_labels))
+        if multi_label:
+            out_label_ids = np.empty((len(to_predict), self.num_labels))
+        else:
+            out_label_ids = np.empty((len(to_predict)))
 
         if not multi_label and self.args.onnx:
             model_inputs = self.tokenizer.batch_encode_plus(
                 to_predict, return_tensors="pt", padding=True, truncation=True
             )
 
-            for input_ids, attention_mask in zip(model_inputs["input_ids"], model_inputs["attention_mask"]):
+            for i, (input_ids, attention_mask) in enumerate(
+                zip(model_inputs["input_ids"], model_inputs["attention_mask"])
+            ):
                 input_ids = input_ids.unsqueeze(0).detach().cpu().numpy()
                 attention_mask = attention_mask.unsqueeze(0).detach().cpu().numpy()
                 inputs_onnx = {"input_ids": input_ids, "attention_mask": attention_mask}
@@ -1124,10 +1151,11 @@ class ClassificationModel:
                 # Run the model (None = get all the outputs)
                 output = self.model.run(None, inputs_onnx)
 
-                if preds is None:
-                    preds = output[0]
-                else:
-                    preds = np.append(preds, output[0], axis=0)
+                preds[i] = output[0]
+                # if preds is None:
+                #     preds = output[0]
+                # else:
+                #     preds = np.append(preds, output[0], axis=0)
 
             model_outputs = preds
             preds = np.argmax(preds, axis=1)
@@ -1171,10 +1199,11 @@ class ClassificationModel:
                 from torch.cuda import amp
 
             if self.config.output_hidden_states:
-                for batch in tqdm(eval_dataloader, disable=args.silent, desc="Running Prediction"):
-                    model.eval()
+                model.eval()
+                preds = None
+                out_label_ids = None
+                for i, batch in enumerate(tqdm(eval_dataloader, disable=args.silent, desc="Running Prediction")):
                     # batch = tuple(t.to(device) for t in batch)
-
                     with torch.no_grad():
                         inputs = self._get_inputs_dict(batch)
 
@@ -1204,8 +1233,8 @@ class ClassificationModel:
                         )
                         all_embedding_outputs = embedding_outputs.detach().cpu().numpy()
                     else:
-                        preds = np.append(preds, logits.detach().cpu().numpy(), axis=0)
-                        out_label_ids = np.append(out_label_ids, inputs["labels"].detach().cpu().numpy(), axis=0)
+                        # preds = np.append(preds, logits.detach().cpu().numpy(), axis=0)
+                        # out_label_ids = np.append(out_label_ids, inputs["labels"].detach().cpu().numpy(), axis=0)
                         all_layer_hidden_states = np.append(
                             all_layer_hidden_states,
                             np.array([state.detach().cpu().numpy() for state in layer_hidden_states]),
@@ -1215,7 +1244,8 @@ class ClassificationModel:
                             all_embedding_outputs, embedding_outputs.detach().cpu().numpy(), axis=0
                         )
             else:
-                for batch in tqdm(eval_dataloader, disable=args.silent):
+                n_batches = len(eval_dataloader)
+                for i, batch in enumerate(tqdm(eval_dataloader, disable=args.silent)):
                     model.eval()
                     # batch = tuple(t.to(device) for t in batch)
 
@@ -1239,12 +1269,17 @@ class ClassificationModel:
 
                     nb_eval_steps += 1
 
-                    if preds is None:
-                        preds = logits.detach().cpu().numpy()
-                        out_label_ids = inputs["labels"].detach().cpu().numpy()
-                    else:
-                        preds = np.append(preds, logits.detach().cpu().numpy(), axis=0)
-                        out_label_ids = np.append(out_label_ids, inputs["labels"].detach().cpu().numpy(), axis=0)
+                    start_index = self.args.eval_batch_size * i
+                    end_index = start_index + self.args.eval_batch_size if i != (n_batches - 1) else len(eval_dataset)
+                    preds[start_index:end_index] = logits.detach().cpu().numpy()
+                    out_label_ids[start_index:end_index] = inputs["labels"].detach().cpu().numpy()
+
+                    # if preds is None:
+                    #     preds = logits.detach().cpu().numpy()
+                    #     out_label_ids = inputs["labels"].detach().cpu().numpy()
+                    # else:
+                    #     preds = np.append(preds, logits.detach().cpu().numpy(), axis=0)
+                    #     out_label_ids = np.append(out_label_ids, inputs["labels"].detach().cpu().numpy(), axis=0)
 
             eval_loss = eval_loss / nb_eval_steps
 
